"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const messages = require("./messages");
const types_1 = require("./types");
/**
 * Creates an Elk Response based on the type of message passed in.
 *
 * @export
 * @param {string} message
 * @returns
 */
function getElkResponse(response) {
    const type = response.substring(2, 4);
    const messageType = types_1.responseTypes.get(type);
    if (messages[messageType]) {
        // Create message instance based on the type of message received.
        const ElkMessage = messages[messageType];
        return new ElkMessage(response);
    }
    else {
        // Message not supported yet. Just return base Elk message.
        return new messages.ElkMessage(null, response);
    }
}
exports.default = getElkResponse;
